==> galaxeus_lib-0.0.56.tar.gz: lib/extension/directory.dart <==
// ignore_for_file: non_constant_identifier_names, unused_catch_stack, empty_catches

import 'package:galaxeus_lib/extension/regexp.dart';
import 'package:universal_io/io.dart';

import "package:path/path.dart" as path;

extension DirectoryHelper on Directory {
  /// Recursively copies a directory + subdirectories into a target directory.
  /// Similar to Copy-Item in PowerShell.
  void copyTo(
    final Directory destination, {
    final List<String> ignoreDirList = const [],
    final List<String> ignoreFileList = const [],
  }) {
    listSync().forEach((final entity) {
      if (entity is Directory) {
        if (ignoreDirList.contains(path.basename(entity.path))) {
          return;
        }
        final newDirectory = Directory(
          path.join(destination.absolute.path, path.basename(entity.path)),
        )..createSync();
        entity.absolute.copyTo(newDirectory);
      } else if (entity is File) {
        if (ignoreFileList.contains(path.basename(entity.path))) {
          return;
        }
        entity.copySync(
          path.join(destination.path, path.basename(entity.path)),
        );
      }
    });
  }

  // void renameRecursive({
  //   required String origin_name,
  //   required String new_name,
  //   final List<String> ignoreDirList = const [],
  //   final List<String> ignoreFileList = const [],
  // }) {

  //   try {
  //     listSync(recursive: true).forEach((FileSystemEntity entity) {
  //       try {
  //         if (entity is Directory) {
  //           if (ignoreDirList.contains(path.basename(entity.path))) {
  //             return;
  //           }
  //           if (RegExp(origin_name, caseSensitive: false).hashData(path.basename(entity.path))) {
  //             var file_path = entity.path.replaceAll(RegExp(origin_name, caseSensitive: false), new_name);
  //             entity.renameSync(file_path);
  //           }
  //           Directory(entity.path).renameRecursive(origin_name: origin_name, new_name: new_name);
  //         } else if (entity is File) {
  //           if (ignoreFileList.contains(path.basename(entity.path))) {
  //             return;
  //           }
  //           try {
  //             String data = entity.readAsStringSync();

  //             if (RegExp(origin_name, caseSensitive: false).hashData(data)) {
  //               entity.writeAsStringSync(data.replaceAll(RegExp(origin_name, caseSensitive: false), new_name));
  //             }
  //           } catch (e) {}

  //           if (RegExp(origin_name, caseSensitive: false).hashData(path.basename(entity.path))) {
  //             var file_path = entity.path.replaceAll(RegExp(origin_name, caseSensitive: false), new_name);
  //             entity.renameSync(file_path);
  //           }
  //           // entity.copySync(
  //           //   path.join(destination.path, path.basename(entity.path)),
  //           // );
  //         }
  //       } catch (e) {}
  //     });
  //   } catch (e) {}
  // }

  void renameRecursive({
    required String origin_name,
    required String new_name,
    final List<String> ignoreDirList = const [],
    final List<String> ignoreFileList = const [],
  }) {
    List<FileSystemEntity> fileSystemEntitys = listSync();
    for (var i = 0; i < fileSystemEntitys.length; i++) {
      FileSystemEntity entity = fileSystemEntitys[i];
      try {
        if (entity is Directory) {
          if (ignoreDirList.contains(path.basename(entity.path))) {
            continue;
          }
          if (RegExp(origin_name, caseSensitive: false).hashData(path.basename(entity.path))) {
            var file_path = entity.path.replaceAll(RegExp(origin_name, caseSensitive: false), new_name);
            entity.renameSync(file_path);
            Directory(file_path).renameRecursive(origin_name: origin_name, new_name: new_name, ignoreDirList: ignoreDirList, ignoreFileList: ignoreFileList);
          } else {
            entity.absolute.renameRecursive(origin_name: origin_name, new_name: new_name, ignoreDirList: ignoreDirList, ignoreFileList: ignoreFileList);
          }
        } else if (entity is File) {
          if (ignoreFileList.contains(path.basename(entity.path))) {
            continue;
          }
          try {
            String data = entity.readAsStringSync();
            if (RegExp(origin_name, caseSensitive: false).hashData(data)) {
              entity.writeAsStringSync(data.replaceAll(RegExp(origin_name, caseSensitive: false), new_name));
            }
          } catch (e) {}

          if (RegExp(origin_name, caseSensitive: false).hashData(path.basename(entity.path))) {
            var file_path = entity.path.replaceAll(RegExp(origin_name, caseSensitive: false), new_name);
            entity.renameSync(file_path);
          }
        }
      } catch (e, stack) {}
    }
    return;
  }



  void renameRecursiveSync({
    required String origin_name,
    required String new_name,
    final List<String> ignoreDirList = const [],
    final List<String> ignoreFileList = const [],
  }) {
    List<FileSystemEntity> fileSystemEntitys = listSync();
    for (var i = 0; i < fileSystemEntitys.length; i++) {
      FileSystemEntity entity = fileSystemEntitys[i];
      try {
        if (entity is Directory) {
          if (ignoreDirList.contains(path.basename(entity.path))) {
            continue;
          }
          if (RegExp(origin_name, caseSensitive: false).hashData(path.basename(entity.path))) {
            var file_path = entity.path.replaceAll(RegExp(origin_name, caseSensitive: false), new_name);
            entity.renameSync(file_path);
            Directory(file_path).renameRecursive(origin_name: origin_name, new_name: new_name, ignoreDirList: ignoreDirList, ignoreFileList: ignoreFileList);
          } else {
            entity.absolute.renameRecursive(origin_name: origin_name, new_name: new_name, ignoreDirList: ignoreDirList, ignoreFileList: ignoreFileList);
          }
        } else if (entity is File) {
          if (ignoreFileList.contains(path.basename(entity.path))) {
            continue;
          }
          try {
            String data = entity.readAsStringSync();
            if (RegExp(origin_name, caseSensitive: false).hashData(data)) {
              entity.writeAsStringSync(data.replaceAll(RegExp(origin_name, caseSensitive: false), new_name));
            }
          } catch (e) {}

          if (RegExp(origin_name, caseSensitive: false).hashData(path.basename(entity.path))) {
            var file_path = entity.path.replaceAll(RegExp(origin_name, caseSensitive: false), new_name);
            entity.renameSync(file_path);
          }
        }
      } catch (e, stack) {}
    }
    return;
  }
}

==> galaxeus_lib-0.0.89.tar.gz: lib/extension/directory.dart <==
// ignore_for_file: non_constant_identifier_names, unused_catch_stack, empty_catches

import 'package:galaxeus_lib/extension/regexp.dart';
import 'package:universal_io/io.dart';

import "package:path/path.dart" as path;

extension DirectoryHelper on Directory {
  /// Recursively copies a directory + subdirectories into a target directory.
  /// Similar to Copy-Item in PowerShell.
  void copyTo(
    final Directory destination, {
    final List<String> ignoreDirList = const [],
    final List<String> ignoreFileList = const [],
  }) {
    listSync().forEach((final entity) {
      if (entity is Directory) {
        if (ignoreDirList.contains(path.basename(entity.path))) {
          return;
        }
        final newDirectory = Directory(
          path.join(destination.absolute.path, path.basename(entity.path)),
        )..createSync();
        entity.absolute.copyTo(newDirectory);
      } else if (entity is File) {
        if (ignoreFileList.contains(path.basename(entity.path))) {
          return;
        }
        entity.copySync(
          path.join(destination.path, path.basename(entity.path)),
        );
      }
    });
  }

  // void renameRecursive({
  //   required String origin_name,
  //   required String new_name,
  //   final List<String> ignoreDirList = const [],
  //   final List<String> ignoreFileList = const [],
  // }) {

  //   try {
  //     listSync(recursive: true).forEach((FileSystemEntity entity) {
  //       try {
  //         if (entity is Directory) {
  //           if (ignoreDirList.contains(path.basename(entity.path))) {
  //             return;
  //           }
  //           if (RegExp(origin_name, caseSensitive: false).hashData(path.basename(entity.path))) {
  //             var file_path = entity.path.replaceAll(RegExp(origin_name, caseSensitive: false), new_name);
  //             entity.renameSync(file_path);
  //           }
  //           Directory(entity.path).renameRecursive(origin_name: origin_name, new_name: new_name);
  //         } else if (entity is File) {
  //           if (ignoreFileList.contains(path.basename(entity.path))) {
  //             return;
  //           }
  //           try {
  //             String data = entity.readAsStringSync();

  //             if (RegExp(origin_name, caseSensitive: false).hashData(data)) {
  //               entity.writeAsStringSync(data.replaceAll(RegExp(origin_name, caseSensitive: false), new_name));
  //             }
  //           } catch (e) {}

  //           if (RegExp(origin_name, caseSensitive: false).hashData(path.basename(entity.path))) {
  //             var file_path = entity.path.replaceAll(RegExp(origin_name, caseSensitive: false), new_name);
  //             entity.renameSync(file_path);
  //           }
  //           // entity.copySync(
  //           //   path.join(destination.path, path.basename(entity.path)),
  //           // );
  //         }
  //       } catch (e) {}
  //     });
  //   } catch (e) {}
  // }

  void renameRecursive({
    required String origin_name,
    required String new_name,
    final List<String> ignoreDirList = const [],
    final List<String> ignoreFileList = const [],
  }) {
    List<FileSystemEntity> fileSystemEntitys = listSync();
    for (var i = 0; i < fileSystemEntitys.length; i++) {
      FileSystemEntity entity = fileSystemEntitys[i];
      try {
        if (entity is Directory) {
          if (ignoreDirList.contains(path.basename(entity.path))) {
            continue;
          }
          if (RegExp(origin_name, caseSensitive: false)
              .hashData(path.basename(entity.path))) {
            var file_path = entity.path.replaceAll(
                RegExp(origin_name, caseSensitive: false), new_name);
            entity.renameSync(file_path);
            Directory(file_path).renameRecursive(
                origin_name: origin_name,
                new_name: new_name,
                ignoreDirList: ignoreDirList,
                ignoreFileList: ignoreFileList);
          } else {
            entity.absolute.renameRecursive(
                origin_name: origin_name,
                new_name: new_name,
                ignoreDirList: ignoreDirList,
                ignoreFileList: ignoreFileList);
          }
        } else if (entity is File) {
          if (ignoreFileList.contains(path.basename(entity.path))) {
            continue;
          }
          try {
            String data = entity.readAsStringSync();
            if (RegExp(origin_name, caseSensitive: false).hashData(data)) {
              entity.writeAsStringSync(data.replaceAll(
                  RegExp(origin_name, caseSensitive: false), new_name));
            }
          } catch (e) {}

          if (RegExp(origin_name, caseSensitive: false)
              .hashData(path.basename(entity.path))) {
            var file_path = entity.path.replaceAll(
                RegExp(origin_name, caseSensitive: false), new_name);
            entity.renameSync(file_path);
          }
        }
      } catch (e, stack) {}
    }
    return;
  }

  void renameRecursiveSync({
    required String origin_name,
    required String new_name,
    final List<String> ignoreDirList = const [],
    final List<String> ignoreFileList = const [],
  }) {
    List<FileSystemEntity> fileSystemEntitys = listSync();
    for (var i = 0; i < fileSystemEntitys.length; i++) {
      FileSystemEntity entity = fileSystemEntitys[i];
      try {
        if (entity is Directory) {
          if (ignoreDirList.contains(path.basename(entity.path))) {
            continue;
          }
          if (RegExp(origin_name, caseSensitive: false)
              .hashData(path.basename(entity.path))) {
            var file_path = entity.path.replaceAll(
                RegExp(origin_name, caseSensitive: false), new_name);
            entity.renameSync(file_path);
            Directory(file_path).renameRecursive(
                origin_name: origin_name,
                new_name: new_name,
                ignoreDirList: ignoreDirList,
                ignoreFileList: ignoreFileList);
          } else {
            entity.absolute.renameRecursive(
                origin_name: origin_name,
                new_name: new_name,
                ignoreDirList: ignoreDirList,
                ignoreFileList: ignoreFileList);
          }
        } else if (entity is File) {
          if (ignoreFileList.contains(path.basename(entity.path))) {
            continue;
          }
          try {
            String data = entity.readAsStringSync();
            if (RegExp(origin_name, caseSensitive: false).hashData(data)) {
              entity.writeAsStringSync(data.replaceAll(
                  RegExp(origin_name, caseSensitive: false), new_name));
            }
          } catch (e) {}

          if (RegExp(origin_name, caseSensitive: false)
              .hashData(path.basename(entity.path))) {
            var file_path = entity.path.replaceAll(
                RegExp(origin_name, caseSensitive: false), new_name);
            entity.renameSync(file_path);
          }
        }
      } catch (e, stack) {}
    }
    return;
  }
}
